@@ -875,7 +875,7 @@ void ci_main (void)
 	redraw = REDRAW_FULL;
       }
       
-      if (redraw == REDRAW_FULL)
+      if (redraw & REDRAW_FULL)
       {
 	clear ();
 	ci_show_last_error ();
@@ -915,8 +915,7 @@ void ci_main (void)
 	}
 	else if (oldcurrent != current)
 	{
-	  if (!redraw)
-	    redraw = REDRAW_MOTION;
+	  if (!redraw) redraw = REDRAW_MOTION;
 	}
       }
 
@@ -1145,10 +1144,10 @@ void ci_main (void)
 
 	CHECK_MSGCOUNT;
 
-	oldcurrent = Context->vcount ? CURHDR->index : -1;
 
 	if (ci_pattern_function (M_LIMIT, "Limit to messages matching: ", CURHDR) == 0)
 	{
+	  oldcurrent = Context->vcount ? CURHDR->index : -1;
 	  if (oldcurrent >= 0)
 	  {
 	    /* try to find what used to be the current message */
