@@ -573,8 +573,9 @@ static int mutt_checkpoint_mailbox (CONTEXT *ctx, int update)
 	  ctx->hdrs[i]->offset = newOffset[i].hdr;
 	  ctx->hdrs[i]->content->hdr_offset = newOffset[i].hdr;
 	  ctx->hdrs[i]->content->offset = newOffset[i].body;
-	  ctx->hdrs[i]->index = j; /* FOO -- WRONG! */
+	  ctx->hdrs[i]->index = j;
 	  ctx->hdrs[i]->msgno = j + 1;
+	  ctx->hdrs[i]->changed = 0;
 	  if (i != j)
 	  {
 	    ctx->hdrs[j] = ctx->hdrs[i];
