@@ -79,7 +79,7 @@ struct binding_t OpMain[] = {
   { "untag-pattern",		OP_MAIN_UNTAG_PATTERN,		"\\ct" },
   { "undelete-message",		OP_UNDELETE,			"u" },
   { "undelete-pattern",		OP_MAIN_UNDELETE_PATTERN,	"U"},
-  { "browse-url",		OP_BROWSE_URL,			"\\cu" },
+  { "browse-url",		OP_BROWSE_URL,			"\\cb" },
   { "view-attachments",		OP_VIEW_ATTACHMENTS,		"v" },
   { "set-flag",			OP_MAIN_SET_FLAG,		"w" },
   { "clear-flag",		OP_MAIN_CLEAR_FLAG,		"W" },
@@ -108,52 +108,52 @@ struct binding_t OpMain[] = {
 };
 
 struct binding_t OpPager[] = {
+  { "create-alias",	OP_CREATE_ALIAS,		"a" },
+  { "bounce-message",	OP_BOUNCE_MESSAGE,		"b" },
+  { "browse-url",	OP_BROWSE_URL,			"\\cb" },
+  { "change-folder",	OP_MAIN_CHANGE_FOLDER,		"c" },
+  { "copy-message",	OP_MAIN_COPY_MESSAGE,		"C" },
+  { "delete-message",	OP_DELETE,			"d" },
+  { "delete-thread",	OP_DELETE_THREAD,		"\\cd" },
+  { "forward-message",	OP_FORWARD_MESSAGE,		"f" },
+  { "flag-message",	OP_FLAG_MESSAGE,		"F" },
+  { "forget-passphrase",OP_FORGET_PASSPHRASE,		"\\cf" },
+  { "group-reply",	OP_GROUP_REPLY,			"g" },
+  { "display-headers",	OP_DISPLAY_HEADERS,		"h" },
+  { "exit",		OP_PAGER_EXIT,			"i" },
+  { "next-undeleted",	OP_MAIN_NEXT_UNDELETED,		"j" },
+  { "next-message",	OP_MAIN_NEXT_MESSAGE,		"J" },
+  { "previous-undeleted",OP_MAIN_PREVIOUS_UNDELETED,	"k" },
+  { "previous-message",	OP_MAIN_PREVIOUS_MESSAGE,	"K" },
+  { "list-reply",	OP_LIST_REPLY,			"L" },
+  { "redraw-screen",	OP_REDRAW,			"\\cl" },
+  { "mail",		OP_MAIL,			"m" },
+  { "mark-as-new",	OP_TOGGLE_NEW,			"N" },
+  { "next-thread",	OP_MAIN_NEXT_THREAD,		"\\cn" },
+  { "print-message",	OP_PRINT,			"p" },
+  { "previous-thread",	OP_MAIN_PREVIOUS_THREAD,	"\\cp" },
+  { "reply",		OP_REPLY,			"r" },
+  { "recall-message",	OP_RECALL_MESSAGE,		"R" },
+  { "save-message",	OP_MAIN_SAVE_MESSAGE,		"s" },
+  { "tag-message",	OP_TAG_MESSAGE,			"t" },
+  { "toggle-quoted",	OP_PAGER_HIDE_QUOTED,		"T" },
+  { "undelete-message",	OP_UNDELETE,			"u" },
+  { "undelete-thread",	OP_UNDELETE_THREAD,		"\\cu" },
+  { "view-attachments",	OP_VIEW_ATTACHMENTS,		"v" },
   { "help",		OP_HELP,			"?" },
   { "next-page",	OP_NEXT_PAGE,			" " },
   { "previous-page",	OP_PREVIOUS_PAGE,		"-" },
   { "next-line",	OP_PAGER_NEXT_LINE,		M_ENTER_S },
   { "top",		OP_PAGER_TOP,			"^" },
   { "bottom",		OP_PAGER_BOTTOM,		"$" },
-  { "exit",		OP_PAGER_EXIT,			"i" },
-  { "search",		OP_PAGER_SEARCH,		"/" },
-  { "toggle-quoted",	OP_PAGER_HIDE_QUOTED,		"T" },
-  { "half-up",		OP_PAGER_HALF_UP,		"\\cp" },
-  { "half-down",	OP_PAGER_HALF_DOWN,		"\\cn" },
-  { "redraw-screen",	OP_REDRAW,			"\\cl" },
   { "invoke-subshell",	OP_SUBSHELL,			"!" },
+  { "search",		OP_PAGER_SEARCH,		"/" },
   { "display-address",	OP_DISPLAY_ADDRESS,		"%" },
-  { "recall-message",	OP_RECALL_MESSAGE,		"R" },
-  { "forget-passphrase",OP_FORGET_PASSPHRASE,	"\\cf" },
-  { "browse-url",	OP_BROWSE_URL,			"\\cu" },
   { "pipe-message",	OP_PIPE_MESSAGE,		"|" },
-  { "mail",		OP_MAIL,			"m" },
-  { "reply",		OP_REPLY,			"r" },
-  { "group-reply",	OP_GROUP_REPLY,			"g" },
-  { "forward-message",	OP_FORWARD_MESSAGE,		"f" },
-  { "list-reply",	OP_LIST_REPLY,			"l" },
-  { "delete-thread",	OP_DELETE_THREAD,		"\\cd" },
-  { "undelete-thread",	OP_UNDELETE_THREAD,		"\\cu" },
-  { "next-thread",	OP_MAIN_NEXT_THREAD,		"\\cn" },
-  { "previous-thread",	OP_MAIN_PREVIOUS_THREAD,	"\\cp" },
-  { "flag-message",	OP_FLAG_MESSAGE,		"F" },
-  { "mark-as-new",	OP_TOGGLE_NEW,			"N" },
-  { "create-alias",	OP_CREATE_ALIAS,		"a" },
-  { "bounce-message",	OP_BOUNCE_MESSAGE,		"b" },
-  { "display-headers",	OP_DISPLAY_HEADERS,		"h" },
-  { "view-attachments",	OP_VIEW_ATTACHMENTS,		"v" },
-  { "change-folder",	OP_MAIN_CHANGE_FOLDER,		"c" },
-  { "next-undeleted",	OP_MAIN_NEXT_UNDELETED,		"n" },
-  { "next-message",	OP_MAIN_NEXT_MESSAGE,		"J" },
-  { "previous-undeleted",	OP_MAIN_PREVIOUS_UNDELETED,	"k" },
-  { "previous-message",	OP_MAIN_PREVIOUS_MESSAGE,	"K" },
-  { "delete-message",	OP_DELETE,			"d" },
-  { "undelete-message",	OP_UNDELETE,			"u" },
-  { "save-message",	OP_MAIN_SAVE_MESSAGE,		"s" },
-  { "copy-message",	OP_MAIN_COPY_MESSAGE,		"C" },
-  { "print-message",	OP_PRINT,			"p" },
   { "next-new",		OP_MAIN_NEXT_NEW,		"\t" },
-  { "tag-message",	OP_TAG_MESSAGE,			"t" },
   { "enter-command",	OP_ENTER_COMMAND,		":" },
+  { "half-up",		OP_PAGER_HALF_UP,		NULL },
+  { "half-down",	OP_PAGER_HALF_DOWN,		NULL },
   { "previous-line",	OP_PAGER_PREVIOUS_LINE,		NULL },
   { "next-unread",	OP_MAIN_NEXT_UNREAD,		NULL },
   { "previous-new",	OP_MAIN_PREV_NEW,		NULL },
