@@ -243,73 +243,74 @@ int main (int argc, char **argv)
   strcpy (Muttrc, "~/.muttrc");
 
   while ((i = getopt (argc, argv, "a:F:f:c:d:s:i:hnpvz")) != EOF)
-    switch(i) {
-    case 'a':
-      {
-	BODY *pattach = attach;
+    switch(i)
+    {
+      case 'a':
+	{
+	  BODY *pattach = attach;
 
-	while (pattach && pattach->next)
-	  pattach = pattach->next;
-	if (pattach)
-	  pattach->next = mutt_make_attach (optarg);
-	else
-	  attach = mutt_make_attach (optarg);
-      }
-      break;
+	  while (pattach && pattach->next)
+	    pattach = pattach->next;
+	  if (pattach)
+	    pattach->next = mutt_make_attach (optarg);
+	  else
+	    attach = mutt_make_attach (optarg);
+	}
+	break;
 
-    case 'F':
-      strfcpy (Muttrc, optarg, sizeof (Muttrc));
-      break;
+      case 'F':
+	strfcpy (Muttrc, optarg, sizeof (Muttrc));
+	break;
 
-    case 'f':
-      strfcpy (folder, optarg, sizeof (folder));
-      break;
+      case 'f':
+	strfcpy (folder, optarg, sizeof (folder));
+	break;
 
-    case 'c':
-      if (!env)
-	env = mutt_new_envelope ();
-      if (mutt_parse_adrlist (&env->cc, optarg, "@") == -1)
-      {
-	fprintf (stderr, "%s: %s\n", optarg, ParseError);
-	exit (0);
-      }
-      break;
+      case 'c':
+	if (!env)
+	  env = mutt_new_envelope ();
+	if (mutt_parse_adrlist (&env->cc, optarg, "@") == -1)
+	{
+	  fprintf (stderr, "%s: %s\n", optarg, ParseError);
+	  exit (0);
+	}
+	break;
 
-    case 'd':
+      case 'd':
 #ifdef DEBUG
-      debuglevel = atoi (optarg);
-      printf ("Debugging at level %d.\n", debuglevel);
+	debuglevel = atoi (optarg);
+	printf ("Debugging at level %d.\n", debuglevel);
 #else
-      printf ("DEBUG was not defined during compilation.  Ignored.\n");
+	printf ("DEBUG was not defined during compilation.  Ignored.\n");
 #endif
-      break;
+	break;
 
-    case 'i':
-      includeFile = optarg;
-      break;
+      case 'i':
+	includeFile = optarg;
+	break;
 
-    case 'n':
-      nosysrc = 1;
-      break;
+      case 'n':
+	nosysrc = 1;
+	break;
 
-    case 'p':
-      sendflags |= SENDPOSTPONED;
-      break;
+      case 'p':
+	sendflags |= SENDPOSTPONED;
+	break;
 
-    case 's':
-      subject = optarg;
-      break;
+      case 's':
+	subject = optarg;
+	break;
 
-    case 'v':
-      show_version ();
-      /* not reached */
+      case 'v':
+	show_version ();
+	/* not reached */
 
-    case 'z':
-      ignore_empty = 1;
-      break;
+      case 'z':
+	ignore_empty = 1;
+	break;
 
-    default:
-      mutt_help ();
+      default:
+	mutt_help ();
     }
 
   memset (Options, 0, sizeof (Options));
@@ -331,7 +332,7 @@ int main (int argc, char **argv)
     ci_send_message (SENDPOSTPONED, NULL, NULL, NULL, NULL);
     ci_endwin (NULL);
   }
-  else if (subject || attach || optind < argc)
+  else if (subject || attach || option (OPTBATCHMODE) || optind < argc)
   {
     if (!env)
       env = mutt_new_envelope ();
