@@ -701,7 +701,14 @@ envelope_defaults (int flags, HEADER *cur, ENVELOPE *en, BODY **at,
 
     en->references = mutt_copy_list (curenv->references);
     if (curenv->message_id)
-      mutt_add_to_list (&en->references, curenv->message_id);
+    {
+      LIST *t;
+
+      t = mutt_new_list ();
+      t->data = safe_strdup (curenv->message_id);
+      t->next = en->references;
+      en->references = t;
+    }
   }
   else if (flags & SENDFORWARD)
   {
